#!/usr/bin/env python3
import requests
import random
import re
import time
import argparse
from bs4 import BeautifulSoup


# Website to fetch from
SITE = "https://billwurtz.com/"


def get_wurtzism():
    # Do two HTTP requests in one session
    session = requests.Session()
    page = session.get(SITE + "notebook.html")

    # Find all links by capital HREF - this is faster than BeautifulSoup
    links = re.findall(r'HREF=[\'"]?([^\'" >]+)', page.text)

    random_link = random.choice(links)
    random_wurtzism = session.get(SITE + random_link)
    wurtzism_soup = BeautifulSoup(random_wurtzism.text, features='html.parser')
    # Post contents are in plan text after </head> tag. We strip the first newline.
    return wurtzism_soup.text.lstrip()


def main():
    parser = argparse.ArgumentParser(description='Wisdom from Bill Wurtz')
    parser.add_argument('--instant', action='store_true', default=False, help='Print instantly')
    args = parser.parse_args()

    wurtzism = get_wurtzism()

    if args.instant:
        print(wurtzism)
    else:
        for char in wurtzism:
            print(char, end='', flush=True)
            # Randomize delay to simulate typing
            sleep_duration = random.randrange(1, 17, 1) / 100
            time.sleep(sleep_duration)
        print()


if __name__ == '__main__':
    main()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="wurtzisms",
    version="1.0.0",
    author="Daniel Andersson",
    author_email="wurtz@muthur6000.se",
    description="Your daily wurtzisms delivered straight to your shell",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/splump/wurtzisms",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)",
        "Operating System :: OS Independent",
    ],
    entry_points={
        'console_scripts': [
            'wurtzisms = wurtzisms.__main__:main'
        ]
    },
    install_requires=['beautifulsoup4==4.6.3', 'requests==2.19.1']
)
